Profiling
=========

time range
----------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.prof.TimeRangeDecorator
   cupy.prof.time_range


Device synchronization detection
--------------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.allow_synchronize
   cupyx.DeviceSynchronized
